CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
123 lines
3.6 KiB
C++
123 lines
3.6 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include <hip_test_common.hh>
|
|
#include <hip_test_defgroups.hh>
|
|
#include <utils.hh>
|
|
#include "streamCommon.hh"
|
|
/**
|
|
* @addtogroup hipStreamSynchronize_spt hipStreamSynchronize_spt
|
|
* @{
|
|
* @ingroup StreamTest
|
|
* `hipStreamSynchronize_spt(hipStream_t stream)` -
|
|
* Query the priority of a stream
|
|
*/
|
|
|
|
/**
|
|
* Test Description
|
|
* ------------------------
|
|
* - Test to verify that hipStreamSynchronize_spt handles empty streams properly.
|
|
* Test source
|
|
* ------------------------
|
|
* - /unit/stream/hipStreamSynchronize_spt.cc
|
|
* Test requirements
|
|
* ------------------------
|
|
* - HIP_VERSION >= 6.2
|
|
*/
|
|
HIP_TEST_CASE(Unit_hipStreamSynchronize_spt_EmptyStream) {
|
|
hipStream_t stream;
|
|
HIP_CHECK(hipStreamCreate(&stream));
|
|
HIP_CHECK(hipStreamSynchronize_spt(stream));
|
|
HIP_CHECK(hipStreamDestroy(stream));
|
|
}
|
|
/**
|
|
* Test Description
|
|
* ------------------------
|
|
* - Check that synchronization of uninitialized stream sets its status to
|
|
* hipErrorContextIsDestroyed
|
|
* Test source
|
|
* ------------------------
|
|
* - /unit/stream/hipStreamSynchronize_spt.cc
|
|
* Test requirements
|
|
* ------------------------
|
|
* - HIP_VERSION >= 6.2
|
|
*/
|
|
|
|
#if HT_AMD
|
|
/**
|
|
* Test Description
|
|
* ------------------------
|
|
* - Check that all work executing in a stream is finished after a call to
|
|
* hipStreamSynchronize_spt.
|
|
* Test source
|
|
* ------------------------
|
|
* - /unit/stream/hipStreamSynchronize_spt.cc
|
|
* Test requirements
|
|
* ------------------------
|
|
* - HIP_VERSION >= 6.2
|
|
*/
|
|
HIP_TEST_CASE(Unit_hipStreamSynchronize_spt_FinishWork) {
|
|
hipStream_t explicitStream = reinterpret_cast<hipStream_t>(-1);
|
|
hipStream_t stream = GENERATE_COPY(explicitStream, hip::nullStream, hip::streamPerThread);
|
|
if (explicitStream) {
|
|
HIP_CHECK(hipStreamCreate(&stream));
|
|
}
|
|
|
|
LaunchDelayKernel(std::chrono::milliseconds(isQuickLevel() ? 100 : 500), stream);
|
|
HIP_CHECK(hipStreamSynchronize_spt(stream));
|
|
HIP_CHECK(hipStreamQuery(stream));
|
|
|
|
if (explicitStream) {
|
|
HIP_CHECK(hipStreamDestroy(stream));
|
|
}
|
|
}
|
|
/**
|
|
* Test Description
|
|
* ------------------------
|
|
* - Check that synchronizing one stream does implicitly synchronize
|
|
* other streams. Check that submiting work to the nullStream does
|
|
* not affect synchronization of other streams. Check that querying
|
|
* the nullStream does not affect synchronization of other streams.
|
|
* Test source
|
|
* ------------------------
|
|
* - /unit/stream/hipStreamSynchronize_spt.cc
|
|
* Test requirements
|
|
* ------------------------
|
|
* - HIP_VERSION >= 6.2
|
|
*/
|
|
|
|
HIP_TEST_CASE(Unit_hipStreamSynchronize_spt_SynchronizeStreamAndQueryNullStream) {
|
|
hipStream_t stream1;
|
|
hipStream_t stream2;
|
|
|
|
HIP_CHECK(hipStreamCreate(&stream1));
|
|
HIP_CHECK(hipStreamCreate(&stream2));
|
|
|
|
LaunchDelayKernel(std::chrono::milliseconds(isQuickLevel() ? 100 : 500), stream1);
|
|
LaunchDelayKernel(std::chrono::milliseconds(isQuickLevel() ? 400 : 2000), stream2);
|
|
hip::stream::empty_kernel<<<1, 1, 0, hip::nullStream>>>();
|
|
|
|
HIP_CHECK_ERROR(hipStreamQuery(stream1), hipErrorNotReady);
|
|
HIP_CHECK_ERROR(hipStreamQuery(stream2), hipErrorNotReady);
|
|
HIP_CHECK_ERROR(hipStreamQuery(hip::nullStream), hipErrorNotReady);
|
|
|
|
HIP_CHECK(hipStreamSynchronize_spt(stream1));
|
|
HIP_CHECK(hipStreamQuery(stream1));
|
|
HIP_CHECK_ERROR(hipStreamQuery(stream2), hipErrorNotReady);
|
|
HIP_CHECK_ERROR(hipStreamQuery(hip::nullStream), hipErrorNotReady);
|
|
|
|
HIP_CHECK(hipStreamSynchronize_spt(stream2));
|
|
HIP_CHECK(hipStreamQuery(stream2));
|
|
|
|
HIP_CHECK(hipStreamDestroy(stream1));
|
|
HIP_CHECK(hipStreamDestroy(stream2));
|
|
}
|
|
#endif
|
|
/**
|
|
* End doxygen group StreamTest.
|
|
* @}
|
|
*/
|